searchData={"items":[{"type":"module","doc":"`IP` provides representations for IP addresses and subnets for Elixir with a\nbunch of helpful stuff tacked on the side.\n\nAlso provides a `__using__` macro so that `use IP` will result in\n`import IP.Sigil`, which is just less typing, yo.","title":"IP","ref":"IP.html"},{"type":"module","doc":"iex> ~i(192.0.2.1)\n    #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::)\n    #IP.Address<2001:db8:: Documentation, GLOBAL, RESERVED>\n\n    iex> outside = ~i(2001:db8::/64)\n    ...> inside  = IP.Prefix.eui_64!(outside, \"60:f8:1d:ad:d8:90\")\n    ...> IP.Prefix.contains_address?(outside, inside)\n    true","title":"Examples - IP","ref":"IP.html#module-examples"},{"type":"module","doc":"Simple representations of IP Addresses.","title":"IP.Address","ref":"IP.Address.html"},{"type":"function","doc":"Returns true if the address is an EUI-64 address.","title":"IP.Address.eui_64?/1","ref":"IP.Address.html#eui_64?/1"},{"type":"function","doc":"iex> ~i(2001:db8::62f8:1dff:fead:d890)\n    ...> |> IP.Address.eui_64?()\n    true","title":"Examples - IP.Address.eui_64?/1","ref":"IP.Address.html#eui_64?/1-examples"},{"type":"function","doc":"Return a MAC address coded in an EUI-64 address.","title":"IP.Address.eui_64_mac/1","ref":"IP.Address.html#eui_64_mac/1"},{"type":"function","doc":"iex> ~i(2001:db8::62f8:1dff:fead:d890)\n    ...> |> IP.Address.eui_64_mac()\n    {:ok, \"60f8.1dad.d890\"}","title":"Examples - IP.Address.eui_64_mac/1","ref":"IP.Address.html#eui_64_mac/1-examples"},{"type":"function","doc":"Convert a 6to4 IPv6 address to it's correlated IPv6 address.","title":"IP.Address.from_6to4/1","ref":"IP.Address.html#from_6to4/1"},{"type":"function","doc":"iex> ~i(2002:c000:201::)\n    ...> |> IP.Address.from_6to4()\n    ...> |> inspect()\n    \"{:ok, #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>}\"\n\n    iex> ~i(2001:db8::)\n    ...> |> IP.Address.from_6to4()\n    {:error, \"Not a 6to4 address\"}","title":"Examples - IP.Address.from_6to4/1","ref":"IP.Address.html#from_6to4/1-examples"},{"type":"function","doc":"Convert from (packed) binary representations (either 32 or 128 bits long) into an address.","title":"IP.Address.from_binary/1","ref":"IP.Address.html#from_binary/1"},{"type":"function","doc":"iex> <<192, 0, 2, 1>>\n    ...> |> IP.Address.from_binary()\n    {:ok, %IP.Address{address: 3221225985, version: 4}}\n\n    iex> <<32, 1, 13, 184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0>>\n    ...> |> IP.Address.from_binary()\n    {:ok, %IP.Address{address: 42540766411282592856903984951653826560, version: 6}}\n\n    iex> \"192.0.2.1\"\n    ...> |> IP.Address.from_binary()\n    {:error, \"Unable to convert binary to address\"}","title":"Examples - IP.Address.from_binary/1","ref":"IP.Address.html#from_binary/1-examples"},{"type":"function","doc":"Convert from a packed binary presentation to an address or raise an\n`IP.Address.InvalidAddress` exception.","title":"IP.Address.from_binary!/1","ref":"IP.Address.html#from_binary!/1"},{"type":"function","doc":"iex> <<192, 0, 2, 1>>\n    ...> |> IP.Address.from_binary!()\n    %IP.Address{address: 3221225985, version: 4}\n\n    iex> <<32, 1, 13, 184, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1>>\n    ...> |> IP.Address.from_binary!()\n    %IP.Address{address: 42540766411282592856903984951653826561, version: 6}","title":"Examples - IP.Address.from_binary!/1","ref":"IP.Address.html#from_binary!/1-examples"},{"type":"function","doc":"Convert an integer into an IP address of specified version.","title":"IP.Address.from_integer/2","ref":"IP.Address.html#from_integer/2"},{"type":"function","doc":"iex> 3221225985\n    ...> |> IP.Address.from_integer(4)\n    {:ok, %IP.Address{address: 3221225985, version: 4}}\n\n    iex> 42540766411282592856903984951653826561\n    ...> |> IP.Address.from_integer(6)\n    {:ok, %IP.Address{address: 42540766411282592856903984951653826561, version: 6}}","title":"Examples - IP.Address.from_integer/2","ref":"IP.Address.html#from_integer/2-examples"},{"type":"function","doc":"Convert an integer into an IP address of specified version or raise an\n`IP.Address.InvalidAddress` exception.","title":"IP.Address.from_integer!/2","ref":"IP.Address.html#from_integer!/2"},{"type":"function","doc":"iex> 3221225985\n    ...> |> IP.Address.from_integer!(4)\n    %IP.Address{address: 3221225985, version: 4}\n\n    iex> 42540766411282592856903984951653826561\n    ...> |> IP.Address.from_integer!(6)\n    %IP.Address{address: 42540766411282592856903984951653826561, version: 6}","title":"Examples - IP.Address.from_integer!/2","ref":"IP.Address.html#from_integer!/2-examples"},{"type":"function","doc":"Convert a string representation into an IP address of unknown version.\n\nTries to parse the string as IPv6, then IPv4 before failing.  Obviously if\nyou know the version then using `from_string/2` is faster.","title":"IP.Address.from_string/1","ref":"IP.Address.html#from_string/1"},{"type":"function","doc":"iex> \"192.0.2.1\"\n    ...> |> IP.Address.from_string()\n    {:ok, %IP.Address{address: 3221225985, version: 4}}\n\n    iex> \"2001:db8::1\"\n    ...> |> IP.Address.from_string()\n    {:ok, %IP.Address{address: 42540766411282592856903984951653826561, version: 6}}","title":"Examples - IP.Address.from_string/1","ref":"IP.Address.html#from_string/1-examples"},{"type":"function","doc":"Convert a string representation into an IP address of specified version.","title":"IP.Address.from_string/2","ref":"IP.Address.html#from_string/2"},{"type":"function","doc":"iex> \"192.0.2.1\"\n    ...> |> IP.Address.from_string(4)\n    {:ok, %IP.Address{address: 3221225985, version: 4}}\n\n    iex> \"2001:db8::1\"\n    ...> |> IP.Address.from_string(6)\n    {:ok, %IP.Address{address: 42540766411282592856903984951653826561, version: 6}}","title":"Examples - IP.Address.from_string/2","ref":"IP.Address.html#from_string/2-examples"},{"type":"function","doc":"Convert a string representation into an IP address or raise an\n`IP.Address.InvalidAddress` exception.","title":"IP.Address.from_string!/1","ref":"IP.Address.html#from_string!/1"},{"type":"function","doc":"iex> \"192.0.2.1\"\n    ...> |> IP.Address.from_string!()\n    %IP.Address{address: 3221225985, version: 4}\n\n    iex> \"2001:db8::1\"\n    ...> |> IP.Address.from_string!()\n    %IP.Address{address: 42540766411282592856903984951653826561, version: 6}","title":"Examples - IP.Address.from_string!/1","ref":"IP.Address.html#from_string!/1-examples"},{"type":"function","doc":"Convert a string representation into an IP address of specified version or raise an\n`IP.Address.InvalidAddress` exception.","title":"IP.Address.from_string!/2","ref":"IP.Address.html#from_string!/2"},{"type":"function","doc":"iex> \"192.0.2.1\"\n    ...> |> IP.Address.from_string!(4)\n    %IP.Address{address: 3221225985, version: 4}\n\n    iex> \"2001:db8::1\"\n    ...> |> IP.Address.from_string!(6)\n    %IP.Address{address: 42540766411282592856903984951653826561, version: 6}","title":"Examples - IP.Address.from_string!/2","ref":"IP.Address.html#from_string!/2-examples"},{"type":"function","doc":"Convert an Erlang-style tuple of bytes to an address.","title":"IP.Address.from_tuple/1","ref":"IP.Address.html#from_tuple/1"},{"type":"function","doc":"iex> {192, 0, 2, 1}\n    ...> |> IP.Address.from_tuple()\n    {:ok, %IP.Address{address: 3221225985, version: 4}}\n\n    iex> {8193, 3512, 0, 0, 0, 0, 0, 1}\n    ...> |> IP.Address.from_tuple()\n    {:ok, %IP.Address{address: 42540766411282592856903984951653826561, version: 6}}","title":"Examples - IP.Address.from_tuple/1","ref":"IP.Address.html#from_tuple/1-examples"},{"type":"function","doc":"Convert an Erlang-style tuple of bytes to an address.","title":"IP.Address.from_tuple!/1","ref":"IP.Address.html#from_tuple!/1"},{"type":"function","doc":"iex> {192, 0, 2, 1}\n    ...> |> IP.Address.from_tuple!()\n    %IP.Address{address: 3221225985, version: 4}\n\n    iex> {8193, 3512, 0, 0, 0, 0, 0, 1}\n    ...> |> IP.Address.from_tuple!()\n    %IP.Address{address: 42540766411282592856903984951653826561, version: 6}","title":"Examples - IP.Address.from_tuple!/1","ref":"IP.Address.html#from_tuple!/1-examples"},{"type":"function","doc":"Generate an IPv6 Unique Local Address\n\nNote that the MAC address is just used as a source of randomness, so where you\nget it from is not important and doesn't restrict this ULA to just that system.\nSee RFC4193","title":"IP.Address.generate_ula/3","ref":"IP.Address.html#generate_ula/3"},{"type":"function","doc":"iex> IP.Address.generate_ula(\"60:f8:1d:ad:d8:90\")\n    #IP.Address","title":"Examples - IP.Address.generate_ula/3","ref":"IP.Address.html#generate_ula/3-examples"},{"type":"type","doc":"Valid IP address","title":"IP.Address.ip/0","ref":"IP.Address.html#t:ip/0"},{"type":"type","doc":"Valid IPv4 address - integer between zero and 32 ones.","title":"IP.Address.ipv4/0","ref":"IP.Address.html#t:ipv4/0"},{"type":"type","doc":"Valid IPv6 address - integer between zero and 128 ones.","title":"IP.Address.ipv6/0","ref":"IP.Address.html#t:ipv6/0"},{"type":"function","doc":"Determine if the IP address is a 6to4 address.","title":"IP.Address.is_6to4?/1","ref":"IP.Address.html#is_6to4?/1"},{"type":"function","doc":"iex> ~i(2002:c000:201::)\n    ...> |> IP.Address.is_6to4?()\n    true\n\n    iex> ~i(2001:db8::)\n    ...> |> IP.Address.is_6to4?()\n    false","title":"Examples - IP.Address.is_6to4?/1","ref":"IP.Address.html#is_6to4?/1-examples"},{"type":"function","doc":"Determine if an IP address is a teredo connection.","title":"IP.Address.is_teredo?/1","ref":"IP.Address.html#is_teredo?/1"},{"type":"function","doc":"iex> ~i(2001::)\n    ...> |> IP.Address.is_teredo?()\n    true","title":"Examples - IP.Address.is_teredo?/1","ref":"IP.Address.html#is_teredo?/1-examples"},{"type":"type","doc":"IP address struct type, contains a valid address and version.","title":"IP.Address.t/0","ref":"IP.Address.html#t:t/0"},{"type":"function","doc":"Return information about a teredo connection.","title":"IP.Address.teredo/1","ref":"IP.Address.html#teredo/1"},{"type":"function","doc":"iex> ~i(2001:0:4136:e378:8000:63bf:3fff:fdd2)\n    ...> |> IP.Address.teredo()\n    ...> |> Map.get(:server)\n    #IP.Address<65.54.227.120 GLOBAL UNICAST>\n\n    iex> ~i(2001:0:4136:e378:8000:63bf:3fff:fdd2)\n    ...> |> IP.Address.teredo()\n    ...> |> Map.get(:client)\n    #IP.Address<63.255.253.210 GLOBAL UNICAST>\n\n    iex> ~i(2001:0:4136:e378:8000:63bf:3fff:fdd2)\n    ...> |> IP.Address.teredo()\n    ...> |> Map.get(:port)\n    25535","title":"Examples - IP.Address.teredo/1","ref":"IP.Address.html#teredo/1-examples"},{"type":"function","doc":"Convert an IPv4 address into a 6to4 address.","title":"IP.Address.to_6to4/1","ref":"IP.Address.html#to_6to4/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.to_6to4()\n    #IP.Address<2002:c000:201:: 6to4, GLOBAL, RESERVED>","title":"Examples - IP.Address.to_6to4/1","ref":"IP.Address.html#to_6to4/1-examples"},{"type":"function","doc":"Returns the IP Address as an integer","title":"IP.Address.to_integer/1","ref":"IP.Address.html#to_integer/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.to_integer()\n    3221225985\n\n    iex> ~i(2001:db8::1)\n    ...> |> IP.Address.to_integer()\n    42540766411282592856903984951653826561","title":"Examples - IP.Address.to_integer/1","ref":"IP.Address.html#to_integer/1-examples"},{"type":"function","doc":"Convert an `address` to an `IP.Prefix`.","title":"IP.Address.to_prefix/2","ref":"IP.Address.html#to_prefix/2"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.to_prefix(32)\n    #IP.Prefix<192.0.2.1/32 Documentation (TEST-NET-1), GLOBAL, RESERVED>","title":"Examples - IP.Address.to_prefix/2","ref":"IP.Address.html#to_prefix/2-examples"},{"type":"function","doc":"Convert an `address` into a string.","title":"IP.Address.to_string/1","ref":"IP.Address.html#to_string/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.to_string()\n    \"192.0.2.1\"\n\n    iex> ~i(2001:db8::1)\n    ...> |> IP.Address.to_string()\n    \"2001:db8::1\"","title":"Examples - IP.Address.to_string/1","ref":"IP.Address.html#to_string/1-examples"},{"type":"function","doc":"Convert an `address` into an Erlang-style tuple.","title":"IP.Address.to_tuple/1","ref":"IP.Address.html#to_tuple/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.to_tuple()\n    {192, 0, 2, 1}\n\n    iex> ~i(2001:db8::1)\n    ...> |> IP.Address.to_tuple()\n    {8193, 3512, 0, 0, 0, 0, 0, 1}","title":"Examples - IP.Address.to_tuple/1","ref":"IP.Address.html#to_tuple/1-examples"},{"type":"function","doc":"Returns true if `address` is version 4.","title":"IP.Address.v4?/1","ref":"IP.Address.html#v4?/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.v4?\n    true\n\n    iex> ~i(2001:db8::)\n    ...> |> IP.Address.v4?\n    false","title":"Examples - IP.Address.v4?/1","ref":"IP.Address.html#v4?/1-examples"},{"type":"function","doc":"Returns true if `address` is version 6.","title":"IP.Address.v6?/1","ref":"IP.Address.html#v6?/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.v6?\n    false\n\n    iex> ~i(2001:db8::)\n    ...> |> IP.Address.v6?\n    true","title":"Examples - IP.Address.v6?/1","ref":"IP.Address.html#v6?/1-examples"},{"type":"type","doc":"Valid IP version (currently only 4 and 6 are deployed in the wild).","title":"IP.Address.version/0","ref":"IP.Address.html#t:version/0"},{"type":"function","doc":"Returns the IP version of the address.","title":"IP.Address.version/1","ref":"IP.Address.html#version/1"},{"type":"function","doc":"iex> ~i(192.0.2.1)\n    ...> |> IP.Address.version()\n    4\n\n    iex> ~i(2001:db8::1)\n    ...> |> IP.Address.version()\n    6","title":"Examples - IP.Address.version/1","ref":"IP.Address.html#version/1-examples"},{"type":"module","doc":"Defines an IP prefix, otherwise known as a subnet.","title":"IP.Prefix","ref":"IP.Prefix.html"},{"type":"function","doc":"Returns `true` or `false` depending on whether the supplied `address` is\ncontained within `prefix`.","title":"IP.Prefix.contains_address?/2","ref":"IP.Prefix.html#contains_address?/2"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.contains_address?(~i(192.0.2.127))\n    true\n\n    iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.contains_address?(~i(198.51.100.1))\n    false\n\n    iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.contains_address?(~i(2001:db8::1))\n    true\n\n    iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.contains_address?(~i(2001:db8:1::1))\n    false\n\n    iex> outside = ~i(2001:db8::/64)\n    ...> inside  = IP.Prefix.eui_64!(outside, \"60:f8:1d:ad:d8:90\")\n    ...> IP.Prefix.contains_address?(outside, inside)\n    true","title":"Examples - IP.Prefix.contains_address?/2","ref":"IP.Prefix.html#contains_address?/2-examples"},{"type":"function","doc":"Returns `true` or `false` depending on whether the supplied `inside` is\ncompletely contained by `outside`.","title":"IP.Prefix.contains_prefix?/2","ref":"IP.Prefix.html#contains_prefix?/2"},{"type":"function","doc":"iex> outside = ~i(192.0.2.0/24)\n    ...> inside  = ~i(192.0.2.128/25)\n    ...> IP.Prefix.contains_prefix?(outside, inside)\n    true\n\n    iex> outside = ~i(192.0.2.128/25)\n    ...> inside  = ~i(192.0.2.0/24)\n    ...> IP.Prefix.contains_prefix?(outside, inside)\n    false\n\n    iex> outside = ~i(2001:db8::/64)\n    ...> inside  = ~i(2001:db8::/128)\n    ...> IP.Prefix.contains_prefix?(outside, inside)\n    true\n\n    iex> outside = ~i(2001:db8::/128)\n    ...> inside  = ~i(2001:db8::/64)\n    ...> IP.Prefix.contains_prefix?(outside, inside)\n    false","title":"Examples - IP.Prefix.contains_prefix?/2","ref":"IP.Prefix.html#contains_prefix?/2-examples"},{"type":"function","doc":"Generate an EUI-64 host address within the specifed IPv6 `prefix`.\n\nEUI-64 addresses can only be generated for 64 bit long IPv6 prefixes.","title":"IP.Prefix.eui_64/2","ref":"IP.Prefix.html#eui_64/2"},{"type":"function","doc":"iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.eui_64(\"60:f8:1d:ad:d8:90\")\n    ...> |> inspect()\n    \"{:ok, #IP.Address<2001:db8::62f8:1dff:fead:d890 Documentation, GLOBAL, RESERVED>}\"","title":"Examples - IP.Prefix.eui_64/2","ref":"IP.Prefix.html#eui_64/2-examples"},{"type":"function","doc":"Generate an EUI-64 host address within the specifed IPv6 `prefix`.\n\nEUI-64 addresses can only be generated for 64 bit long IPv6 prefixes.","title":"IP.Prefix.eui_64!/2","ref":"IP.Prefix.html#eui_64!/2"},{"type":"function","doc":"iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.eui_64!(\"60:f8:1d:ad:d8:90\")\n    #IP.Address<2001:db8::62f8:1dff:fead:d890 Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Prefix.eui_64!/2","ref":"IP.Prefix.html#eui_64!/2-examples"},{"type":"function","doc":"Returns the first address in the prefix.","title":"IP.Prefix.first/1","ref":"IP.Prefix.html#first/1"},{"type":"function","doc":"iex> ~i(192.0.2.128/24)\n    ...> |> IP.Prefix.first()\n    #IP.Address<192.0.2.0 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::128/64)\n    ...> |> IP.Prefix.first()\n    #IP.Address<2001:db8:: Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Prefix.first/1","ref":"IP.Prefix.html#first/1-examples"},{"type":"function","doc":"Create a prefix by attempting to parse a string of unknown version.\n\nCalling `from_string/2` is faster if you know the IP version of the prefix.","title":"IP.Prefix.from_string/1","ref":"IP.Prefix.html#from_string/1"},{"type":"function","doc":"iex> \"192.0.2.1/24\"\n    ...> |> IP.Prefix.from_string()\n    ...> |> inspect()\n    \"{:ok, #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>}\"\n\n    iex> \"192.0.2.1/255.255.255.0\"\n    ...> |> IP.Prefix.from_string()\n    ...> |> inspect()\n    \"{:ok, #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>}\"\n\n    iex> \"2001:db8::/64\"\n    ...> |> IP.Prefix.from_string()\n    ...> |> inspect()\n    \"{:ok, #IP.Prefix<2001:db8::/64 Documentation, GLOBAL, RESERVED>}\"","title":"Examples - IP.Prefix.from_string/1","ref":"IP.Prefix.html#from_string/1-examples"},{"type":"function","doc":"Create a prefix by attempting to parse a string of specified IP version.","title":"IP.Prefix.from_string/2","ref":"IP.Prefix.html#from_string/2"},{"type":"function","doc":"iex> \"192.0.2.1/24\"\n    ...> |> IP.Prefix.from_string(4)\n    ...> |> inspect()\n    \"{:ok, #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>}\"\n\n    iex> \"192.0.2.1/255.255.255.0\"\n    ...> |> IP.Prefix.from_string(4)\n    ...> |> inspect()\n    \"{:ok, #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>}\"\n\n    iex> \"2001:db8::/64\"\n    ...> |> IP.Prefix.from_string(4)\n    {:error, \"Error parsing IPv4 prefix\"}","title":"Examples - IP.Prefix.from_string/2","ref":"IP.Prefix.html#from_string/2-examples"},{"type":"function","doc":"Create a prefix by attempting to parse a string of unknown version.\n\nCalling `from_string!/2` is faster if you know the IP version of the prefix.","title":"IP.Prefix.from_string!/1","ref":"IP.Prefix.html#from_string!/1"},{"type":"function","doc":"iex> \"192.0.2.1/24\"\n    ...> |> IP.Prefix.from_string!()\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> \"192.0.2.1/255.255.255.0\"\n    ...> |> IP.Prefix.from_string!()\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> \"2001:db8::/64\"\n    ...> |> IP.Prefix.from_string!()\n    #IP.Prefix<2001:db8::/64 Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Prefix.from_string!/1","ref":"IP.Prefix.html#from_string!/1-examples"},{"type":"function","doc":"Create a prefix by attempting to parse a string of specified IP version.","title":"IP.Prefix.from_string!/2","ref":"IP.Prefix.html#from_string!/2"},{"type":"function","doc":"iex> \"192.0.2.1/24\"\n    ...> |> IP.Prefix.from_string!(4)\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> \"192.0.2.1/255.255.255.0\"\n    ...> |> IP.Prefix.from_string!(4)\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>","title":"Examples - IP.Prefix.from_string!/2","ref":"IP.Prefix.html#from_string!/2-examples"},{"type":"type","doc":"Valid IPv4 prefix lengths from 0 to 32.","title":"IP.Prefix.ipv4_prefix_length/0","ref":"IP.Prefix.html#t:ipv4_prefix_length/0"},{"type":"type","doc":"Valid IPv6 prefix lengths from 0 to 128.","title":"IP.Prefix.ipv6_prefix_length/0","ref":"IP.Prefix.html#t:ipv6_prefix_length/0"},{"type":"function","doc":"Returns the last address in the prefix.","title":"IP.Prefix.last/1","ref":"IP.Prefix.html#last/1"},{"type":"function","doc":"iex> ~i(192.0.2.128/24)\n    ...> |> IP.Prefix.last()\n    #IP.Address<192.0.2.255 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::128/64)\n    ...> |> IP.Prefix.last()\n    #IP.Address<2001:db8::ffff:ffff:ffff:ffff Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Prefix.last/1","ref":"IP.Prefix.html#last/1-examples"},{"type":"function","doc":"Returns the bit-length of the prefix.","title":"IP.Prefix.length/1","ref":"IP.Prefix.html#length/1"},{"type":"function","doc":"iex> ~i(192.0.2.1/24)\n    ...> |> IP.Prefix.length()\n    24","title":"Example - IP.Prefix.length/1","ref":"IP.Prefix.html#length/1-example"},{"type":"function","doc":"Alter the bit-`length` of the `prefix`.","title":"IP.Prefix.length/2","ref":"IP.Prefix.html#length/2"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.length(25)\n    #IP.Prefix<192.0.2.0/25 Documentation (TEST-NET-1), GLOBAL, RESERVED>","title":"Example - IP.Prefix.length/2","ref":"IP.Prefix.html#length/2-example"},{"type":"function","doc":"Returns the calculated mask of the prefix.","title":"IP.Prefix.mask/1","ref":"IP.Prefix.html#mask/1"},{"type":"function","doc":"iex> ~i(192.0.2.1/24)\n    ...> |> IP.Prefix.mask()\n    0b11111111111111111111111100000000","title":"Example - IP.Prefix.mask/1","ref":"IP.Prefix.html#mask/1-example"},{"type":"function","doc":"Create an IP prefix from an `IP.Address` and `length`.","title":"IP.Prefix.new/2","ref":"IP.Prefix.html#new/2"},{"type":"function","doc":"iex> IP.Prefix.new(~i(192.0.2.1), 24)\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> IP.Prefix.new(~i(2001:db8::1), 64)\n    #IP.Prefix<2001:db8::/64 Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Prefix.new/2","ref":"IP.Prefix.html#new/2-examples"},{"type":"type","doc":"Valid IP prefix length.","title":"IP.Prefix.prefix_length/0","ref":"IP.Prefix.html#t:prefix_length/0"},{"type":"function","doc":"Return the address space within this address.","title":"IP.Prefix.space/1","ref":"IP.Prefix.html#space/1"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.space()\n    256\n\n    iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.space()\n    18446744073709551616","title":"Examples - IP.Prefix.space/1","ref":"IP.Prefix.html#space/1-examples"},{"type":"function","doc":"Returns an old-fashioned subnet mask for IPv4 prefixes.","title":"IP.Prefix.subnet_mask/1","ref":"IP.Prefix.html#subnet_mask/1"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.subnet_mask()\n    #IP.Address<255.255.255.0 Reserved, GLOBAL, RESERVED>","title":"Example - IP.Prefix.subnet_mask/1","ref":"IP.Prefix.html#subnet_mask/1-example"},{"type":"type","doc":"The main prefix type, contains an address and a mask value.","title":"IP.Prefix.t/0","ref":"IP.Prefix.html#t:t/0"},{"type":"function","doc":"Return the usable IP address space within this address.","title":"IP.Prefix.usable/1","ref":"IP.Prefix.html#usable/1"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.usable()\n    254\n\n    iex> ~i(2001:db8::/64)\n    ...> |> IP.Prefix.usable()\n    18446744073709551616","title":"Examples - IP.Prefix.usable/1","ref":"IP.Prefix.html#usable/1-examples"},{"type":"function","doc":"Returns an \"cisco style\" wildcard mask for IPv4 prefixes.","title":"IP.Prefix.wildcard_mask/1","ref":"IP.Prefix.html#wildcard_mask/1"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Prefix.wildcard_mask()\n    #IP.Address<0.0.0.255 This network, GLOBAL, RESERVED>","title":"Example - IP.Prefix.wildcard_mask/1","ref":"IP.Prefix.html#wildcard_mask/1-example"},{"type":"module","doc":"Simple parser for IANA special registry files using Saxy.","title":"IP.RegistryParser","ref":"IP.RegistryParser.html"},{"type":"function","doc":"Parse a registry file from the priv directory.","title":"IP.RegistryParser.parse/1","ref":"IP.RegistryParser.html#parse/1"},{"type":"function","doc":"Raising version of `parse/1`","title":"IP.RegistryParser.parse!/1","ref":"IP.RegistryParser.html#parse!/1"},{"type":"module","doc":"Implements scope lookup for all (currently) known scopes.\n\nPlease open a pull-request if this needs changing.","title":"IP.Scope","ref":"IP.Scope.html"},{"type":"function","doc":"Return the scope of `address`","title":"IP.Scope.address_scope/1","ref":"IP.Scope.html#address_scope/1"},{"type":"function","doc":"iex> ~i(192.0.2.0)\n    ...> |> IP.Scope.address_scope()\n    \"Documentation (TEST-NET-1), GLOBAL, RESERVED\"\n\n    iex> ~i(2001:db8::)\n    ...> |> IP.Scope.address_scope()\n    \"Documentation, GLOBAL, RESERVED\"","title":"Examples - IP.Scope.address_scope/1","ref":"IP.Scope.html#address_scope/1-examples"},{"type":"function","doc":"Return the scope of `prefix`","title":"IP.Scope.prefix_scope/1","ref":"IP.Scope.html#prefix_scope/1"},{"type":"function","doc":"iex> ~i(192.0.2.0/24)\n    ...> |> IP.Scope.prefix_scope()\n    \"Documentation (TEST-NET-1), GLOBAL, RESERVED\"\n\n    iex> ~i(2001:db8::/32)\n    ...> |> IP.Scope.prefix_scope()\n    \"Documentation, GLOBAL, RESERVED\"","title":"Examples - IP.Scope.prefix_scope/1","ref":"IP.Scope.html#prefix_scope/1-examples"},{"type":"module","doc":"Provides the `~i` sigil.\n\nYou can use with `import IP.Sigil` or `use IP`.\n\nValid modifiers are `f` to parse specifically as an IPv4 value, and `s` to\nparse specifically as an IPv6 value.  As a side note, digits can't be used as\nsigil modifiers. Ask me how I know.\n\n`~i` will raise `IP.Sigil.InvalidValue` in the event of a parsing failure.","title":"IP.Sigil","ref":"IP.Sigil.html"},{"type":"module","doc":"iex> ~i(192.0.2.1/32)\n    #IP.Prefix<192.0.2.1/32 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(192.0.2.1)f\n    #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::/32)\n    #IP.Prefix<2001:db8::/32 Documentation, GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::/32)s\n    #IP.Prefix<2001:db8::/32 Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Sigil","ref":"IP.Sigil.html#module-examples"},{"type":"function","doc":"Implements `sigil_i` for parsing IP addresses and prefixes.\n\n* `value` is a string which will be passed to `IP.Prefix.from_string` and\n  `IP.Address.from_string` sequentially.\n\n* `options` is a charlist of flags provided to the sigil.  Valid flags are:\n  - `f` parse string specifically as an IPv4 value.\n  - `s` parse string specifically as an IPv6 value.","title":"IP.Sigil.sigil_i/2","ref":"IP.Sigil.html#sigil_i/2"},{"type":"function","doc":"iex> IP.Sigil.sigil_i(\"192.0.2.1\", ~c\"\")\n    #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> IP.Sigil.sigil_i(\"192.0.2.0/24\", ~c\"\")\n    #IP.Prefix<192.0.2.0/24 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> IP.Sigil.sigil_i(\"2001:db8::/32\", ~c\"\")\n    #IP.Prefix<2001:db8::/32 Documentation, GLOBAL, RESERVED>\n\n    iex> IP.Sigil.sigil_i(\"2001:db8::\", ~c\"\")\n    #IP.Address<2001:db8:: Documentation, GLOBAL, RESERVED>\n\n    iex> IP.Sigil.sigil_i(\"Marty McFly\", ~c\"\")\n    ** (IP.Sigil.InvalidValue) Unable to parse \"Marty McFly\" as an IP address or prefix.\n\n    iex> IP.Sigil.sigil_i(\"192.0.2.1\", ~c\"f\")\n    #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> IP.Sigil.sigil_i(\"2001:db8::/32\", ~c\"f\")\n    ** (IP.Sigil.InvalidValue) Unable to parse \"2001:db8::/32\" as an IPv4 address or prefix.\n\n    iex> IP.Sigil.sigil_i(\"192.0.2.1\", ~c\"s\")\n    ** (IP.Sigil.InvalidValue) Unable to parse \"192.0.2.1\" as an IPv6 address or prefix.\n\n    iex> IP.Sigil.sigil_i(\"2001:db8::/32\", ~c\"s\")\n    #IP.Prefix<2001:db8::/32 Documentation, GLOBAL, RESERVED>","title":"Examples - IP.Sigil.sigil_i/2","ref":"IP.Sigil.html#sigil_i/2-examples"},{"type":"task","doc":"A mix task which downloads the latest special purpose address registries from\nthe IANA website and stores them in this package's priv directory.","title":"mix ip.refresh_scopes","ref":"Mix.Tasks.Ip.RefreshScopes.html"},{"type":"exception","doc":"An exception raised by the bang-version functions in `IP.Address` when the\nsupplied value is invalid.","title":"IP.Address.InvalidAddress","ref":"IP.Address.InvalidAddress.html"},{"type":"exception","doc":"An exception raised by the bang-version functions in `IP.Prefix` when the\nsupplied value is invalid.","title":"IP.Prefix.InvalidPrefix","ref":"IP.Prefix.InvalidPrefix.html"},{"type":"exception","doc":"An exception raised when `IP.Sigil.sigil_i` fails.","title":"IP.Sigil.InvalidValue","ref":"IP.Sigil.InvalidValue.html"},{"type":"extras","doc":"# IP\n\n[![Build Status](https://drone.harton.dev/api/badges/james/ip/status.svg)](https://drone.harton.dev/james/ip)\n[![Hex.pm](https://img.shields.io/hexpm/v/ip.svg)](https://hex.pm/packages/ip)\n[![Hippocratic License HL3-FULL](https://img.shields.io/static/v1?label=Hippocratic%20License&message=HL3-FULL&labelColor=5e2751&color=bc8c3d)](https://firstdonoharm.dev/version/3/0/full.html)\n\nIP, IP, Ooray! Simple IP Address representations.","title":"IP","ref":"readme.html"},{"type":"extras","doc":"IP is available on [Hex](https://hex.pm/packages/ip) the package can be\ninstalled by adding `ip` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ip, \"~> 2.1.2\"}\n  ]\nend\n```","title":"Installation - IP","ref":"readme.html#installation"},{"type":"extras","doc":"Documentation for the latest release is available on\n[Hexdocs](https://hexdocs.pm/ip) and for the `main` branch on\n[docs.harton.nz](https://docs.harton.nz/james/ip).","title":"Documentation - IP","ref":"readme.html#documentation"},{"type":"extras","doc":"`ip` provides representations for IP addresses and subnets for Elixir with a bunch of helpful stuff tacked on the side.\n\n    iex> ~i(192.0.2.1)\n    #IP.Address<192.0.2.1 Documentation (TEST-NET-1), GLOBAL, RESERVED>\n\n    iex> ~i(2001:db8::)\n    #IP.Address<2001:db8:: Documentation, GLOBAL, RESERVED>\n\n    iex> outside = ~i(2001:db8::/64)\n    ...> inside  = IP.Prefix.eui_64!(outside, \"60:f8:1d:ad:d8:90\")\n    ...> IP.Prefix.contains_address?(outside, inside)\n    true","title":"Usage - IP","ref":"readme.html#usage"},{"type":"extras","doc":"This repository is mirrored [on Github](https://github.com/jimsynz/ip)\nfrom it's primary location [on my Forgejo instance](https://harton.dev/james/ip).\nFeel free to raise issues and open PRs on Github.","title":"Github Mirror - IP","ref":"readme.html#github-mirror"},{"type":"extras","doc":"This software is licensed under the terms of the\n[HL3-FULL](https://firstdonoharm.dev), see the `LICENSE.md` file included with\nthis package for the terms.\n\nThis license actively proscribes this software being used by and for some\nindustries, countries and activities. If your usage of this software doesn't\ncomply with the terms of this license, then [contact me](mailto:james@harton.nz)\nwith the details of your use-case to organise the purchase of a license - the\ncost of which may include a donation to a suitable charity or NGO.","title":"License - IP","ref":"readme.html#license"},{"type":"extras","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v2.1.2](https://harton.dev/james/ip/compare/v2.1.1...v2.1.2) (2025-03-11)","title":"Change Log","ref":"changelog.html"},{"type":"extras","doc":"* conditionally compile the registry parser when saxy is present.\n\n## [v2.1.1](https://harton.dev/james/ip/compare/v2.1.0...v2.1.1) (2025-03-07)","title":"Bug Fixes: - Change Log","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* widen type constraints on `from_string` parsing. (#93)\n\n## [v2.1.0](https://harton.dev/james/ip/compare/v2.0.3...v2.1.0) (2025-03-07)","title":"Improvements: - Change Log","ref":"changelog.html#improvements"},{"type":"extras","doc":"* Use IANA's registrys directly for address scopes. (#92)\n\n## [v2.0.3](https://harton.dev/james/ip/compare/v2.0.2...v2.0.3) (2024-03-14)","title":"Features: - Change Log","ref":"changelog.html#features"},{"type":"extras","doc":"* use types from `:inet` rather than `:socket`.\n\n## [v2.0.2](https://harton.dev/james/ip/compare/v2.0.1...v2.0.2) (2024-02-23)\n\n\n\n\n## [v2.0.1](https://harton.dev/james/ip/compare/v2.0.0...v2.0.1) (2023-10-03)","title":"Improvements: - Change Log","ref":"changelog.html#improvements"},{"type":"extras","doc":"- Add `IP.Address.to_tuple/1`.\n\n## [v2.0.0](https://harton.dev/james/ip/compare/v1.2.3...v2.0.0) (2023-01-16)","title":"Improvements: - Change Log","ref":"changelog.html#improvements"},{"type":"extras","doc":"- Relicense to HL3-FULL.\n\n## [v1.2.3](https://harton.dev/james/ip/compare/v1.2.2...v1.2.3) (2022-10-03)","title":"Breaking Changes: - Change Log","ref":"changelog.html#breaking-changes"},{"type":"extras","doc":"- Add :crypto to extra_applications\n\n## [v1.2.2](https://harton.dev/james/ip/compare/v1.2.1...v1.2.2) (2022-09-27)","title":"Improvements: - Change Log","ref":"changelog.html#improvements"},{"type":"extras","doc":"- Update Bitwise use, libs\n\n## [v1.2.1](https://harton.dev/james/ip/compare/v1.2.0...v1.2.1) (2022-09-22)","title":"Improvements: - Change Log","ref":"changelog.html#improvements"},{"type":"extras","doc":"- correctly validate IPv4 netmasks\n\n## [v1.2.0](https://harton.dev/james/ip/compare/v1.1.1...v1.2.0) (2022-03-01)","title":"Bug Fixes: - Change Log","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"- add `Address.from_tuple/1` and `Address.from_tuple!/1`\n\n## [v1.1.1](https://harton.dev/james/ip/compare/v1.1.1...v1.1.1) (2021-12-08)","title":"Features: - Change Log","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}